summaryrefslogtreecommitdiff
path: root/lib/sigpipe.h
diff options
context:
space:
mode:
authorDaniel Stenberg <daniel@haxx.se>2016-06-21 15:47:12 +0200
committerDaniel Stenberg <daniel@haxx.se>2016-06-22 10:28:41 +0200
commit434f8d0389f2969b393ff81ead713b7600502f27 (patch)
treeba8ab5c680bad171a7a98b8594fa6432fb15bfbd /lib/sigpipe.h
parent9adf3c473a01b289c781aab111f9ad2fc541ed4e (diff)
downloadgnurl-434f8d0389f2969b393ff81ead713b7600502f27.tar.gz
gnurl-434f8d0389f2969b393ff81ead713b7600502f27.tar.bz2
gnurl-434f8d0389f2969b393ff81ead713b7600502f27.zip
internals: rename the SessionHandle struct to Curl_easy
Diffstat (limited to 'lib/sigpipe.h')
-rw-r--r--lib/sigpipe.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/sigpipe.h b/lib/sigpipe.h
index 6559c7424..800f9d3b4 100644
--- a/lib/sigpipe.h
+++ b/lib/sigpipe.h
@@ -38,10 +38,10 @@ struct sigpipe_ignore {
* internals, and then sigpipe_restore() will restore the situation when we
* return from libcurl again.
*/
-static void sigpipe_ignore(struct SessionHandle *data,
+static void sigpipe_ignore(struct Curl_easy *data,
struct sigpipe_ignore *ig)
{
/* get a local copy of no_signal because the SessionHandle might not be
around when we restore */
ig->no_signal = data->set.no_signal;
if(!data->set.no_signal) {
@@ -38,10 +38,10 @@ struct sigpipe_ignore {
struct sigpipe_ignore *ig)
{
- /* get a local copy of no_signal because the SessionHandle might not be
+ /* get a local copy of no_signal because the Curl_easy might not be
around when we restore */
ig->no_signal = data->set.no_signal;